@@ -3,6 +3,7 @@ import pyorbit.subroutines.constants as constants
 import pyorbit.subroutines.kepler_exo as kepler_exo
 from pyorbit.models.abstract_model import AbstractModel
 from pyorbit.models.abstract_transit import AbstractTransit
+import multiprocessing
 
 try:
     import batman
@@ -45,8 +46,13 @@ class Batman_Transit_With_TTV(AbstractModel, AbstractTransit):
         self._prepare_limb_darkening_coefficients(mc, **kwargs)
 
         self.code_options['nthreads'] = kwargs.get('nthreads', 1)
-        print('Warning: OpenMP computation on batman temporaroly turned off ')
-        self.code_options['nthreads'] = 1
+        try:
+            import multiprocessing
+            if self.code_options['nthreads'] > multiprocessing.cpu_count():
+                print('Batman nthreads automatically lowered to the maximum CPU count')
+                self.code_options['nthreads'] = multiprocessing.cpu_count()
+        except:
+            self.code_options['nthreads'] = 1
 
         self.batman_params = batman.TransitParams()
 
